FrameTime

Struct FrameTime 

pub struct FrameTime {
    pub delta_seconds: f32,
    pub seconds: f32,
    pub frame_time: Instant,
    /* private fields */
}
Keeps track of Timing useful for Games. it keeps track of Delta Seconds and Seconds since the start of the program.

Fields

delta_seconds: f32

Time between each update call.

seconds: f32

Seconds and Milliseconds since program start.

frame_time: Instant

last Instant::Now() since update()

Implementations

Source

impl FrameTime

pub fn delta_seconds(&self) -> f32

Returns Delta Second and Delta Milliseconds since last update call.

pub fn new() -> Self

Creates the FrameTime and sets its Start Timer.

pub fn new_recent() -> Self

Creates the FrameTime and sets its Start Timer based on recent().

pub fn seconds(&self) -> f32

Returns Seconds and Milliseconds since Start of program.

pub fn update(&mut self)

Updates the Timer to get the current Seconds and Delta Seconds via now()

pub fn update_recent(&mut self)

Updates the Timer to get the current Seconds and Delta Seconds from the stored timer that is handled by the updater.